Starting points
===============

:date: 2023-10-28 09:00
:author: tundish
:tags: python, balladeer, game jam
:category: Blog
:status: draft
:summary: In which we spring into action

Copy an Example
~~~~~~~~~~~~~~~

Example 12 is about styles and procedural dialogue.
There's a slight possibility of including images, but not a priority right now.


* Check PyPI for package name availability.
* Use hatchling  https://pypi.org/project/hatchling/ as build backend.

* Walk the dog.
